"""
Oteilo - A collection of intuitive Python utilities for common development tasks.

This package provides utilities for:
- File I/O operations (JSON, images, temp files)
- Type and requirement validation
- Performance monitoring and timing
- Logging configuration and utilities
- Functional programming utilities
- Pipeline processing with validation
"""

from . import io
from . import validation
from . import timing
from . import logging
from . import functional
from . import pipeline

# I/O utilities
from .io import (
    load_json,
    save_json,
    load_image,
    save_image,
    temp_path,
    get_file_info,
)

# Validation utilities
from .validation import (
    validate_type,
    validate_requirements,
    validate_callable,
)

# Timing utilities
from .timing import (
    timing_block,
    Timer,
)

# Logging utilities
from .logging import (
    configure_logging,
    log_dict,
    log_stage_execution,
    log_validation_errors,
    StageLogger,
)

# Functional utilities
from .functional import (
    compose,
    pipe,
    curry,
    maybe,
    memoize,
    trace,
    Pipeline as FunctionalPipeline,
)

# Pipeline utilities
from .pipeline import (
    Step,
    Pipeline,
    StepMetadata,
)

__version__ = "0.1.0"
__all__ = [
    # Modules
    'io',
    'validation',
    'timing',
    'logging',
    'functional',
    'pipeline',
    
    # I/O utilities
    'load_json',
    'save_json',
    'load_image',
    'save_image',
    'temp_path',
    'get_file_info',
    
    # Validation utilities
    'validate_type',
    'validate_requirements',
    'validate_callable',
    
    # Timing utilities
    'timing_block',
    'Timer',
    
    # Logging utilities
    'configure_logging',
    'log_dict',
    'log_stage_execution',
    'log_validation_errors',
    'StageLogger',
    
    # Functional utilities
    'compose',
    'pipe',
    'curry',
    'maybe',
    'memoize',
    'trace',
    'FunctionalPipeline',
    
    # Pipeline utilities
    'Step',
    'Pipeline',
    'StepMetadata',
]
